@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '0.34';
+our $VERSION = '0.37';
 
 sub new {
 	my ($class) = @_;
@@ -524,7 +524,12 @@ sub PT::ListElement::X {
     return (       $class->{Number}
                 || $class->{String}
                 || $class->{ArrayList}
-                || $class->{HashRef} )->X($className);
+                || $class->{HashRef}
+				|| $class->{ClassFunctionReturn}
+				|| $class->{FunctionReturn}
+				|| $class->{ArrayElement}
+				|| $class->{HashElement}
+				|| $class->{VariableName} )->X($className);
 }
 
 sub PT::HashDeclaration::X {
@@ -581,7 +586,9 @@ sub PT::PairValue::X {
 		|| $class->{HashRef}
 		|| $class->{VariableName}
 		|| $class->{ArrayElement}
-		|| $class->{HashElement} )->X($className);
+		|| $class->{HashElement}
+		|| $class->{ClassFunctionReturn}
+		|| $class->{FunctionReturn} )->X($className);
 }
 
 sub PT::FunctionCall::X {
@@ -905,7 +912,6 @@ sub PT::Return::X {
 	} else {
 		return "return;";
 	}
-
 }
 
 sub PT::Last::X {
@@ -1078,15 +1084,16 @@ my $parser = qr {
     <objrule:  PT::ArrayDeclaration>           <Var> <VariableName> <Equal> <ArrayList> <SemiColon>
     <objrule:  PT::ArrayList>                  <LBracket> <ListElements> <RBracket>
     <objrule:  PT::ListElements>               .{0} | <[ListElement]>+ % <Comma>
-    <objrule:  PT::ListElement>                <Number> | <String> | <ArrayList> | <HashRef>
+    <objrule:  PT::ListElement>                <Number> | <String> | <ClassFunctionReturn> | <FunctionReturn>
+											   | <ArrayElement> | <HashElement> | <ArrayList> | <HashRef> | <VariableName>
 
     <objrule:  PT::HashDeclaration>            <Var> <VariableName> <Equal> <HashRef> <SemiColon>
     <objrule:  PT::HashRef>                    <LBrace> <KeyValuePairs> <RBrace>
     <objrule:  PT::KeyValuePairs>              .{0} | <[KeyValue]>+ % <Comma>
     <objrule:  PT::KeyValue>                   <PairKey> <Colon> <PairValue>
     <objrule:  PT::PairKey>                    <Number> | <String>
-    <objrule:  PT::PairValue>                  <Number> | <String> | <ArrayList> | <HashRef>
-											   | <VariableName> | <ArrayElement> | <HashElement>
+    <objrule:  PT::PairValue>                  <Number> | <String> | <ClassFunctionReturn> | <FunctionReturn>
+											   | <ArrayElement> | <HashElement> | <ArrayList> | <HashRef> | <VariableName>
 
     <objrule:  PT::FunctionCall>               <FunctionName> <LParen> <Parameters>? <RParen> <SemiColon>
     <objrule:  PT::Parameters>                 <[Param]>+ % <Comma>
@@ -1186,7 +1193,6 @@ sub parse {
 1;
 __END__
 
-
 =head1 NAME
 
 Lang::HL HL programming language.
@@ -1229,4 +1235,5 @@ Copyright (C) 2022 by Rajkumar Reddy. All rights reserved.
 
 Open Source.
 
+
 =cut
